@@ -1,11 +1,10 @@
 package Sys::Info::Driver::Linux;
+$Sys::Info::Driver::Linux::VERSION = '0.7904';
 use strict;
 use warnings;
-use vars qw( $VERSION @ISA @EXPORT );
 use base qw( Exporter );
 
-$VERSION = '0.7903';
-@EXPORT  = qw( proc );
+our @EXPORT = qw( proc );
 
 use constant proc => { ## no critic (NamingConventions::Capitalization)
     loadavg  => '/proc/loadavg', # average cpu load
@@ -24,9 +23,17 @@ use constant proc => { ## no critic (NamingConventions::Capitalization)
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Driver::Linux - Linux driver for Sys::Info
+Sys::Info::Driver::Linux
+
+=head1 VERSION
+
+version 0.7904
 
 =head1 SYNOPSIS
 
@@ -34,11 +41,12 @@ Sys::Info::Driver::Linux - Linux driver for Sys::Info
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7903> of C<Sys::Info::Driver::Linux>
-released on C<8 May 2013>.
-
 This is the main module in the C<Linux> driver collection.
 
+=head1 NAME
+
+Sys::Info::Driver::Linux - Linux driver for Sys::Info
+
 =head1 METHODS
 
 None.
@@ -51,15 +59,13 @@ Automatically exported. Includes paths to several files.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.14.2 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
