@@ -1,11 +1,9 @@
 package Sys::Info::Driver::Linux::Constants;
+$Sys::Info::Driver::Linux::Constants::VERSION = '0.7904';
 use strict;
 use warnings;
-use vars qw( $VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS );
 use base qw( Exporter );
 
-$VERSION = '0.7903';
-
 # uptime
 use constant UP_TIME          => 0;
 use constant IDLE_TIME        => 1;
@@ -41,7 +39,7 @@ use constant RE_LINUX_VERSION2 => qr{
    ([a-zA-Z0-9.]+)?
 }xmsi;
 
-%EXPORT_TAGS = (
+our %EXPORT_TAGS = (
     uptime => [qw/
                     UP_TIME
                     IDLE_TIME
@@ -63,41 +61,48 @@ use constant RE_LINUX_VERSION2 => qr{
                     /],
 );
 
-@EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
+our @EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Driver::Linux::Constants - Constants for Linux driver
+Sys::Info::Driver::Linux::Constants
+
+=head1 VERSION
+
+version 0.7904
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7903> of C<Sys::Info::Driver::Linux::Constants>
-released on C<8 May 2013>.
-
 Constants for Linux driver.
 
+=head1 NAME
+
+Sys::Info::Driver::Linux::Constants - Constants for Linux driver
+
 =head1 METHODS
 
 None.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.14.2 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
