@@ -1,15 +1,14 @@
 package Sys::Info::Driver::Linux::Device::CPU;
+$Sys::Info::Driver::Linux::Device::CPU::VERSION = '0.7904';
 use strict;
 use warnings;
-use vars qw($VERSION);
 use base qw(Sys::Info::Base);
+
 use Sys::Info::Driver::Linux;
 use Unix::Processors;
 use POSIX ();
 use Carp qw( croak );
 
-$VERSION = '0.7903';
-
 sub identify {
     my $self = shift;
 
@@ -89,9 +88,17 @@ sub _parse_cpuinfo {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Driver::Linux::Device::CPU - Linux CPU Device Driver
+Sys::Info::Driver::Linux::Device::CPU
+
+=head1 VERSION
+
+version 0.7904
 
 =head1 SYNOPSIS
 
@@ -99,11 +106,12 @@ Sys::Info::Driver::Linux::Device::CPU - Linux CPU Device Driver
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7903> of C<Sys::Info::Driver::Linux::Device::CPU>
-released on C<8 May 2013>.
-
 Identifies the CPU with L<Unix::Processors>, L<POSIX> and C<< /proc >>.
 
+=head1 NAME
+
+Sys::Info::Driver::Linux::Device::CPU - Linux CPU Device Driver
+
 =head1 METHODS
 
 =head2 identify
@@ -127,15 +135,13 @@ proc filesystem.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.14.2 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
