@@ -1,14 +1,13 @@
 package Sys::Info::Driver::Linux::OS::Distribution::Conf;
+$Sys::Info::Driver::Linux::OS::Distribution::Conf::VERSION = '0.7904';
 use strict;
 use warnings;
-use vars qw( $VERSION @EXPORT %CONF );
 use base qw( Exporter );
 use Config::General ();
 
-$VERSION = '0.7903';
-@EXPORT  = qw( %CONF );
+our @EXPORT  = qw( %CONF );
 
-%CONF = Config::General::ParseConfig( -String => <<'RAW' );
+our %CONF = Config::General::ParseConfig( -String => <<'RAW' );
 # Some parts of this data set was initially taken from Wikipedia
 
 <adamantix>
@@ -236,28 +235,33 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Driver::Linux::OS::Distribution::Conf - Distro configuration
+Sys::Info::Driver::Linux::OS::Distribution::Conf
+
+=head1 VERSION
+
+version 0.7904
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7903> of C<Sys::Info::Driver::Linux::OS::Distribution::Conf>
-released on C<8 May 2013>.
+=head1 NAME
+
+Sys::Info::Driver::Linux::OS::Distribution::Conf - Distro configuration
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.14.2 or,
-at your option, any later version of Perl 5 you may have available.
 =cut
